setwd(dirname(parent.frame(2)$ofile))
library(ggplot2)

#-------------------------------------

myModel = inlineModel("
[COVARIATE]
input={p_F}
DEFINITION:
gender = { type=categorical, 
           categories={M,F},
           P(gender=F)=p_F }

[INDIVIDUAL]
input={k_pop, omega_k, gender, beta_F}
gender={type=categorical,categories={M,F}}
DEFINITION:
k = { distribution=lognormal,
      reference=k_pop,
      covariate=gender,
      coefficient={0,beta_F},
      sd=omega_k }

[LONGITUDINAL]
input =  {k, a}
EQUATION:
f = exp(-k*t)
DEFINITION:
y = {distribution=normal, prediction=f, sd=a}
")

p <- list(name=c('p_F','k_pop','omega_k','beta_F','a'), 
          value=c(0.4,0.2,0.1,0.6,0.01))
f <- list(name='f', time=seq(0, 30, by=0.1))
y <- list(name='y', time=seq(1, 30, by=3))
ind <- list(name="gender")
out <- list(ind, f, y)
g = list(size=12,level='covariate');
s=list(seed=12345)
res <- simulx(model=myModel,parameter=p,output=out,group=g, settings=s)

plot1 <- ggplot() + 
  geom_line(data=res$f, aes(x=time, y=f, colour=id), size=0.5) + 
  geom_point(data=res$y, aes(x=time, y=y, colour=id))
print(plot1)

