setwd(dirname(parent.frame(2)$ofile))
library(ggplot2)

#-------------------------------------

myModel = inlineModel("
[COVARIATE]
input={w_pop, omega_w, p_A, p_B}
DEFINITION:
w   = { distribution=normal,
        mean=w_pop,
        sd=omega_w }
trt = { type=categorical, categories={TA,TB,TC},
        P(trt=TA)=p_A,
        P(trt=TB)=p_B }

[INDIVIDUAL]
input={k_pop, omega_k, w, trt}
trt={type=categorical,categories={TA,TB,TC}}
EQUATION:
lw70=log(w/70)
DEFINITION:
k = { distribution=lognormal,
      reference=k_pop,
      covariate={lw70,trt},
      coefficient={0.2,{-0.6,0,0.8}},
      sd=omega_k }

[LONGITUDINAL]
input =  {k, a}
EQUATION:
f = exp(-k*t)

DEFINITION:
y = {distribution=normal, prediction=f, sd=a}
")

p <- list(name=c('w_pop','omega_w','p_A','p_B','k_pop','omega_k','a'), 
          value=c(70,15,0.2,0.4,0.2,0.05,0.01))
f <- list(name='f', time=seq(0, 30, by=0.1))
y <- list(name='y', time=seq(1, 30, by=3))
ind <- list(name=c('w','k','trt'))
out <- list(ind, f, y)
g = list(size=200,level='covariate');
res <- simulx(model=myModel,parameter=p,output=out,group=g)

plot1 <- ggplot() + 
  geom_line(data=res$f, aes(x=time, y=f, colour=id), size=0.5) + 
  geom_point(data=res$y, aes(x=time, y=y, colour=id))+
  theme(legend.position="none")
print(plot1)

