simulx <- function(model=NULL,group=NULL,treatment=NULL,parameter=NULL,output=NULL,
                   data=NULL, project=NULL, settings=NULL)
{ 
  # ########################################################################################  
  #  simulx.R is governed by the CeCILL-B license. 
  #  You can  use, modify and/ or redistribute the software under the terms of 
  #  the CeCILL license as circulated by CEA, CNRS and INRIA at the following URL
  #  http://www.cecill.info/index.en.html
  #
  #  simulx.R was developed by Marc Lavielle and Fazia Bellal (Inria) for the DDMoRe project. 
  # ########################################################################################  
  
  session=Sys.getenv("session.simulx")
  Sys.setenv(LIXOFT_HOME=session)
  
  ############################################################################################# 
  # Manage settings
  #############################################################################################     
  cc  <-  processing_setting(settings)
  s <- cc[2]
  data.in <- cc[1]
  
  
  if(is.null(data)){
    
    # ###########################################################################################
    #    # Initialization
    # ###########################################################################################
    dataIndividual  <- list()
    dataIn          <- list()
    nbIndsParam     <- 0
    nbIndsadmin     <- 0
    nbIndsoutput    <- 0
    dataGroup       <- list(TASK = list(),INDIVIDUAL=list(), GROUP=list())
    task            <- list(LOAD_DESIGN=TRUE)
    
    ############################################################################################
    #    MODEL
    # ###########################################################################################  
    if (!(is.null(model))) {
      if(model=="pkmodel"){
        model = generateModelFromPkModel(parameter,output) 
      } else {
        model_ext <- file_ext(model)
        if(model_ext=="xml"){
          model = pharmml2mlxtran(model)
        }
      }
    }
    
    # ###########################################################################################
    #     Monolix project
    # ########################################################################################### 
    if (!(is.null(project)))  
    {
      ans           <- processing_monolix(project,model, treatment, parameter, output )
      model         <- ans$model
      treatment     <- ans$treatment
      parameter     <- ans$param
      output        <- ans$output
    }
    
    #############################################################################################  
    # Manage parameters
    # ###########################################################################################   
    if (!(is.null(parameter)))  {
      parameter    <- processing_parameter(parameter)
      nbIndsParam  <- parameter$nbInds
      if (!is.null(attributes(parameter$singleParam))){
        population_parameter <- list(NAME  =  parameter$singleParam$name[[1]], 
                                     VALUE =  parameter$singleParam$value[[1]]) 
        dataIn  <-  c(dataIn, list(POPULATION_PARAMETERS = population_parameter))
      }
    }
    
    # ###########################################################################################
    #  Manage sources
    # ###########################################################################################  
    if (!(is.null(treatment))){
      ans         <- processing_treatment(treatment)
      treatment   <- ans$treatment
      nbIndsadmin <- ans$nbInds
    }
    
    # ###########################################################################################
    # Manage outputs
    # ###########################################################################################  
    if (!(is.null(output))) {
      output       <- processing_output(output)
      nbIndsoutput <- output$nbInds
    }
    
    ############################################################################################# 
    # Manage groups
    ############################################################################################# 
    nb_group  <- max(c(nbIndsParam, nbIndsadmin, nbIndsoutput))    
    ans       <- processing_group(group,treatment, output,parameter$multiParam,nb_group );
    group     <- ans$group
    iop_group <- ans$iop_group
    
    ############################################################################################# 
    # Manage targets
    #############################################################################################     
    result  <-  processing_target(group)
    group   <- result$group
    depot   <- result$depot
    if  (!(is.null(depot)))
      dataIn  <-  c(dataIn,list(DEPOT   = depot))
    
    ############################################################################################# 
    # Manage data 
    ############################################################################################# 
    dataIn    <-  processing_data(dataIn,group)
    dataIn$MODEL <- model
    
    # ###########################################################################################
    # #    Call mlxCompute connector
    # ###########################################################################################
  }
  
  if(is.null(s[[1]])){
    argList <- list(DATA=dataIn) 
  } else {
    argList <- list(DATA=dataIn, SETTINGS=s)       
  }
  
  dataOut  <- .Call( "mlxComputeR", argList)
  
  if(is.null(data)){
    dataOut        <- convertmlx(dataOut,group,iop_group)
    if(data.in==F){
      return(dataOut)
    }else{
      path <- Sys.getenv("mlxtoolbox.path")
      source(file.path(path,'src/src_mlx/outputToList.R'))
      return(list(dataOut, dataIn))
    }
  }else{
    return(dataOut)
  }
}
