processing_group  <-  function(group,treatment, output,paramInd,nb_group  )
{
#processing_group 
#
#    group = processing_group(param)
#       handles group according to wether it exist or not.
#       return a new structure group or the modified input one if already
#       exist.
#        
  iop_group=0
  if  (!(is.null(group))) {   
    #if group exists, then it is formatted
    if ((mode(group[[1]])!="list") || (length(group) == 1)){
      group <- list(group)
    }
    for (i in 1:length(group)){
      group[[i]]  <-  formatGroup(group[[i]], treatment, output)
    }     
    iop_group=1
  } else{
    #if group does not exist, then it is created
    group     <-  createGroup(treatment, paramInd, output, nb_group)
  }
  return(list(group=group, iop_group= iop_group))
}

formatGroup  <- function(group,treatment,output)
{
  #formatGroup 
  #
  #   group = formatGroup(group,admin,output)
  #       checks and format structure admin, parameter and output structures in group 
  #            Set admin and output if they do not exist in group    
  #        
  
  isADMIN   <-  (!(is.null(treatment)))
  #isPARAM  <-  (!(is.null(param)))
  isOUTPUT  <-  (!(is.null(output)))
  
  
  if(mode(group)=="list"){
    ########################################################################
    #          Manage inputs
    ########################################################################
    hasADMIN  <- isfield(group,'treatment')
    hasPARAM  <- isfield(group,'parameter')
    hasOUTPUT <- isfield(group,'output')
    
    if (isADMIN && hasADMIN){
      stop('treatment exists but group contains treatment') 
    }else if(isOUTPUT && hasOUTPUT){
      stop('output exists but group contains output')
    }else if(!isOUTPUT && !hasOUTPUT){
      stop('output must be provided')
      #
    }else{
      
      ########################################################################
      #           manage designs
      ########################################################################
      if (isADMIN | hasADMIN){
        if (hasADMIN){
          treatment <- processing_treatment(group$treatment)
          nbInds    = treatment$nbInds
          treatment = treatment$treatment
          if (nbInds!=1){
            stop('treatment format is incorrect inside a group')
          }
        }
        idx   <- 1
        group <- treatmentToGroup(group, treatment, idx)
      }
      
      ########################################################################
      #          manage parameters
      ########################################################################
      if (hasPARAM){
        parameter <-  processing_parameter(group$parameter)
        if (parameter$nbInds!=1)
          stop('parameter format is incorrect inside a group')
        
        
        if (!(is.null(attributes(parameter$singleParam)))){
          group$parameter$name     <- parameter$singleParam$name[[1]]
          #group$parameter$label   <- paramPop$label
          group$parameter$value    <- parameter$singleParam$value[[1]]
        }
      }
      
      ########################################################################
      #            manage output
      ########################################################################
      if (hasOUTPUT){ 
        output  <-  processing_output(group$output)
        if (output$nbInds!=1)
          stop('output format is incorrect inside a group')
      }
      
      if  (!(is.null(attributes(output$output_individual)))){
        idx   <-1
        group <- outputToGroup( group, output, idx)
      }else
        stop('individual output should not be empty')
      if (!(is.null(output$output_group$name))){
        idx <-1              
        group$output_group$name   <- c(group$output_group$name , output$output_group$name[[idx]])
        group$output_group$label  <- c(group$output_group$label ,output$output_group$label[[idx]])
        #group$output_group$label  <- c(group$output_group$label ,output$outputGroup$label[[idx]])
      }
      
      ########################################################################
      #            manage size et level
      ########################################################################
      if (!isfield(group, 'size'))
        group$size  <- 1
      
      if (!isfield(group, 'level'))
        group$level  <- 'longitudinal'
    }
  }else
    stop('group must be a list')
  return(group)
}

createGroup <-  function(treatment, paramInd, output, nb_group)
{
  #createGroup 
  #
  #   group = createGroup(admin, paramInd, output, nb_group)
  #       create a group based on paramInd and output structure and the
  #       number of group nb_group  
  
  group=list()
  #depot <- treatment$depot
  for (i in 1 : nb_group) {
    group[[i]] <- list(size= 1, level=c('longitudinal'))
    
    ## manage individual parameters in group structure     
    if  (!(is.null(attributes(paramInd)))){
      idx <- which(paramInd$id==i)
      if (length(idx)!=0){
        parameter <- list(name    = paramInd$name[[idx]], 
                          label   = paramInd$label[[idx]], 
                          value   = paramInd$value[[idx]])
        group[[i]] <- c( group[[i]], parameter = list(parameter))
      }
    }
    ## manage administration in group structure     
    if  (!(is.null(treatment))) {   
      idx <- which(treatment$id==i)
      if (length(idx)==0){
        idx <- 1
      }  
      ##a implémenter
      group[[i]] <- treatmentToGroup( group[[i]], treatment, idx)
    }
    
    ## manage output in group structure 
    
    if (!(is.null(attributes(output$output_individual)))){
      idx <- which(output$output_individual$id==i)
      if  (length(idx)==0){
        idx  <- 1
      }   
      ##a implémenter
      group[[i]] <- outputToGroup( group[[i]], output, idx)
    }else{
      stop('individual output should not be empty')
    }
    
    
    if (!(is.null(attributes(output$output_group)))){
      idx <- which(output$output_group$id==i)
      if  (length(idx)==0){
        idx <- 1
      }         
      group[[i]]$output_group$name   <- c(group[[i]]$output_group$name ,output$output_group$name[[idx]]) 
      group[[i]]$output_group$label  <- c(group[[i]]$output_group$label ,output$output_group$label[[idx]])
    }
  }   
  return(group)
}

outputToGroup  <-  function( group, output, idx)
{
  #  individual field
  OUTPUT_INDIVIDUAL  <-  list(time  = output$output_individual$time[[idx]],
                              name  = output$output_individual$name[[idx]], 
                              label = output$output_individual$label[[idx]]) 
  #  group field
  OUTPUT_GROUP       <-  list(name  = output$output_individual$name[[idx]],  
                              label = output$output_individual$label[[idx]])
  
  group              <-  c(group,output_individual = list(OUTPUT_INDIVIDUAL), 
                           output_group=list(OUTPUT_GROUP))
  return(group)
}


treatmentToGroup <- function(group, admin, idx)
{
  administration <- list(time   = admin$time[[idx]],
                         amount = admin$amount[[idx]],
                         rate   = admin$rate[[idx]],
                         type   = admin$type[[idx]])
  
  
  if (isfield(admin,'target'))
    administration   <- c(administration,   list(target = admin$target[[idx]]))
  
  group$treatment=administration
  return(group)
}
