processing_output = function(output)
{
  #processing_output 
  #
  #    processing_output(output)
  #       The return results are : 
  #           - outputIndividual : contains all population parameters  
  #           - outputGroup      : contains all individual parameters  
  #           - nbInds           : contains the number of differents individuals
  #                                dealing with the output structure
  #        
  #
  if (mode(output[[1]])!="list")
    output <- list(output)
  
 
  nb_output = length(output);
  # format any single output list
  for (i in 1:nb_output){
    output[[i]] <- formatOutput(output[[i]])
  }
   
  # get the number of individuals over all output list
  nbInds=rep(0,length(output))
  for (i in 1:nb_output){
    nbInds[i] <- length(unique(output[[i]]$id))
  }
  
  
  if (length(unique(nbInds))!=1)
  {
    n_max=max(nbInds);
    for (i in 1 : length(output))
    {
      if (length(unique(output[[i]]$id))==1)
      {
        output[[i]]$name  = replicateLField(output[[i]]$name,n_max);
        output[[i]]$label = replicateLField(output[[i]]$label,n_max);
        output[[i]]$id    = 1:n_max;
        if (isfield(output[[i]],'time'))
        {
          output[[i]]$time  = replicateListField(output[[i]]$time,n_max);
          #output[[i]]$time  = repmat(output[[i]]$time',1,n_max);                  
        }
      }
    }
  }
  
   
  
  # get which output has a field "time"
  outputtimes <- rep(0,length(output))
  for (i in 1:nb_output){
    if (isfield(output[[i]], 'time')){
      outputtimes[i] <- 1
    }
  }
  
  
  ## manage output for individual field
  outputIndividual = list(name=NULL, label=NULL, id=NULL, time=list());
  idx_times  = which(outputtimes==1);
  if (length(idx_times)!=0){

    for (i in 1 : length(idx_times)){
       outputIndividual$name  <- c(outputIndividual$name , output[[idx_times[i]]]$name[[1]])
       outputIndividual$label <- c(outputIndividual$label, output[[idx_times[i]]]$label[[1]])
       outputIndividual$id    <- c(outputIndividual$id,    output[[idx_times[i]]]$id)
       outputIndividual$time  <- c(outputIndividual$time,  output[[idx_times[i]]]$time)
    }
    outputIndividual$name  <- tolist(outputIndividual$name)
    outputIndividual$label <- tolist(outputIndividual$label)

    u_id <- unique(outputIndividual$id);
    temp <- list(name  = list(), 
                 label = list(), 
                 time  = vector("list",length(u_id)), 
                 id    = NULL)
    for (i in 1 : length(u_id)){
      idx                 <-  which(outputIndividual$id==u_id[i])
      temp$name[[i]]      <-  outputIndividual$name[[1]][idx[1]]
      temp$label[[i]]     <-  outputIndividual$label[[1]][idx[1]]
      temp$time[[i]] <- list()
      length(temp$time[[i]]) <- length(idx)
      temp$time[[i]][[1]] <-  outputIndividual$time[[idx[1]]]
 

    j <- 2
    while (j <=length(idx)){
      temp$name[[i]]      <- c(temp$name[[i]] , outputIndividual$name[[1]][idx[j]])
      temp$label[[i]]     <- c(temp$label[[i]], outputIndividual$label[[1]][idx[j]])
      temp$time[[i]][[j]] <- outputIndividual$time[[idx[j]]]
      j <- j+1
    }
  }
    temp$id          <- u_id
    outputIndividual <- temp
  }
  
  
  ## manage output for group field
  outputGroup <- list(name=NULL, label=NULL, id=NULL)
  idx_times  <-  which(outputtimes==0)
  if (length(idx_times)!=0){   
    for (i in 1 : length(idx_times)){
      outputGroup$name   <- c(outputGroup$name, output[[idx_times[i]]]$name[[1]])
      outputGroup$label  <- c(outputGroup$label,output[[idx_times[i]]]$label[[1]])
      outputGroup$id     <- c(outputGroup$id,   output[[idx_times[i]]]$id)
    }
    
       
    u_id <- unique(outputGroup$id)
    temp <- list(name=list(), label=list())
    for (i in 1 : length(u_id)){    
      idx <- which(outputGroup$id==u_id[i]);
      temp$name[[i]]  <- outputGroup$name[[idx[1]]]
      temp$label[[i]] <- outputGroup$label[[idx[1]]]
      j <- 2
      while (j <=length(idx)){
        temp$name[[i]]  <- c(temp$name[[i]] ,outputGroup$name[[idx[j]]])
        temp$label[[i]] <- c(temp$label[[i]],outputGroup$label[[idx[j]]])
        j <- j+1
      }
    }
    temp$id     <- u_id
    outputGroup <- temp
  }
  nbInds <- max(nbInds)
  output <- list(output_individual = outputIndividual, 
                 output_group      = outputGroup,nbInds=nbInds)
  return(output)
}


formatOutput  <- function (output)
{
  #formatOutput 
  #
  #   formatOutput(param)
  #       checks fields in param structure and formats it by setting default field value
  #            Set the good global format   
  defaultID      <- defaultFieldValue('id') 
  defaultLABEL   <- defaultFieldValue('label')
  
  if(mode(output)=="list"){
    hasNAME   <- isfield(output,"name")
    hasVALUE  <- isfield(output,"value")
    hasHEADER <- isfield(output,"header")
    if (!hasNAME){
      stop('output must have NAME as a field')      
    } else if (!hasVALUE && hasHEADER){
      stop('output with a HEADER must have VALUE as a field')
    } else if (!hasHEADER && hasVALUE){
      stop('output with a VALUE must have HEADER as a field')
    } else if (hasHEADER && hasVALUE){
      output <- addFieldsFromHeader(output)
    }
    # Expected field: NAME, ID, TIME, LABEL
    nbFields <- 4;
    # creation fields if necessary
    if (isfield(output,"id")==FALSE) 
      output$id= defaultID
    if (isfield(output,"label")==FALSE) 
      output$label= defaultLABEL
    if (length(names(output)) > nbFields)
      stop('presence of unexpected fields in output')
    
    # format if necessary
    output$name <-  replicateLField(output$name,length(output$id))
    dimNAME     <- length(output$name[[1]]);
    if (isfield(output,"time")){
      output$time  = tolist(output$time )
      if(dimNAME!=length(output$time)) 
        output$time  = replicateListField(output$time,dimNAME)
    }
    
    output$id    <- tovector(output$id,dimNAME)
    output$label <-  replicateLField(output$label,length(output$id))
  } else
    stop('output must be a list')
  return(output)
}