processing_parameter  <-  function(param)
{
  processing_parameter 
  #
  #   processing_parameter(param)
  #       The return results are : 
  #           - singleParam : contains all population parameters  
  #           - multiParam  : contains all individual parameters 
  #           - nbInds           : contains the number of differents individuals
  #                                dealing with the param structure
  #        
  
  singleParam = list();
  multiParam  = list();
  
  if (mode(param[[1]])!="list"){
    param=list(param)
  }
  
  
  # format any single parameter list
  for (i in 1:length(param)){
    param[[i]] <- formatParameter(param[[i]]);
  }

  # get the number of individuals over all param cell
  nbInds=rep(0,length(param));
  for (i in 1:length(param)){
      nbInds[i]=length(unique(param[[i]]$id));
  }
  
  ## manage population parameters    
  idx_paramPop  = which(nbInds==1);
  if (length(idx_paramPop)!=0) {
    singleParam=list(name  = param[[idx_paramPop[1]]]$name, 
                     value = param[[idx_paramPop[1]]]$value);  
    i <- 2
    while (i <=length(idx_paramPop)){
      singleParam$name[[1]]  =  c(singleParam$name[[1]],  param[[idx_paramPop[i]]]$name[[1]]);
      singleParam$value[[1]] =  c(singleParam$value[[1]], param[[idx_paramPop[i]]]$value[[1]]);
      i <- i+1
    }
  }
   
  ## manage individual parameters 
  idx_paramInd  = which(nbInds!=1) ;
  if (length(idx_paramInd)!=0){
    #check if the number of individuals are identicals in all parameter set
    tmp = nbInds[idx_paramInd[1]];
    i <- 2
    while (i <=length(idx_paramInd)){
        if (tmp!=nbInds[idx_paramInd[i]]){
            stop('number of individuals in param dismatch')
        }
        i <- i+1
    }        
    multiParam = list(name  = param[[idx_paramInd[1]]]$name,
                      value = param[[idx_paramInd[1]]]$value,
                      label = param[[idx_paramInd[1]]]$label,
                      id    = param[[idx_paramInd[1]]]$id)

    i <- 2
    while (i <=length(idx_paramInd)){
          multiParam$name[[1]]    =  c(multiParam$name[[1]],  param[[idx_paramInd[i]]]$name[[1]]);
          multiParam$label[[1]]   =  c(multiParam$label[[1]],  param[[idx_paramInd[i]]]$label[[1]]);
          multiParam$value[[1]]   =  cbind(multiParam$value[[1]],  param[[idx_paramInd[i]]]$value[[1]]);     
          multiParam$id           =  c(multiParam$id,  param[[idx_paramInd[i]]]$id);
          i <- i+1
    }
    multiParam$id          = unique(multiParam$id );
    
    temp=list(name=NULL, label=NULL, value=NULL)
    for (i in 1 : length(multiParam$id)){
      temp$name[[i]]  = multiParam$name[[1]];
      temp$label[[i]] = multiParam$label[[1]];
      if (is.matrix(multiParam$value[[1]]))
        temp$value[[i]] = multiParam$value[[1]][i,]
      else
        temp$value[[i]] = multiParam$value[[1]][i]  
    }
    temp$id  = multiParam$id;
    multiParam = temp;
  }
    nbInds <- max(nbInds);
    param <- list(singleParam=singleParam, multiParam=multiParam,nbInds=nbInds)
    return(param)
}

formatParameter  <- function (param)
{
  #formatParameter 
  #
  #   param = formatParameter(param)
  #       checks fields in param structure and formats it by setting default field value
  #            Set the good global format    
  
  defaultLABEL   <- defaultFieldValue('label')
  
  if(mode(param)=="list"){
    hasNAME   <- isfield(param,"name")
    hasVALUE  <- isfield(param,"value")
    hasHEADER <- isfield(param,"header")
    if (!hasNAME){
      stop('param must have NAME as a field')      
    } else if (!hasVALUE){
      stop('param must have VALUE as a field')
    } else if (hasHEADER){
      param <- addFieldsFromHeader(param);
    }
    
    # add fields with default values if necessary
    if (is.matrix(param$value)){
      nbId <- dim(param$value)[1]
    }else if(is.vector(param$value)){
      nbId <- 1
    }
    
    if (isfield(param,"id")==FALSE) 
      param$id= seq(from=1, to=nbId, by=1) 
    if (isfield(param,"label")==FALSE) 
      param$label= defaultLABEL
    
    
    param$name  <- tolist(param$name)
    param$value <- tolist(param$value)
    param$label <- tolist(param$label)
    
    # Expected field: NAME, ID, LABEL, VALUE
    nbFields <- 4
    if (length(names(param)) > nbFields)
      stop('presence of unexpected fields in param')   
  } else
    stop('param must be a list')
  param
}
